@@ -4,16 +4,16 @@ use super::{
     DrawableComponent,
 };
 use crate::{
-    accessors, keys, queue::Queue, strings, ui::style::Theme,
+    accessors, keys, queue::Queue, strings::commands,
+    ui::style::SharedTheme,
 };
 use anyhow::Result;
 use asyncgit::{
-    sync, AsyncDiff, AsyncNotification, DiffParams, DiffType,
+    sync::{CommitId, Tags},
+    AsyncDiff, AsyncNotification, DiffParams, DiffType,
 };
 use crossbeam_channel::Sender;
 use crossterm::event::Event;
-use strings::commands;
-use sync::{CommitId, Tags};
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
@@ -31,7 +31,7 @@ pub struct InspectCommitComponent {
 
 impl DrawableComponent for InspectCommitComponent {
     fn draw<B: Backend>(
-        &mut self,
+        &self,
         f: &mut Frame<B>,
         rect: Rect,
     ) -> Result<()> {
@@ -75,28 +75,24 @@ impl Component for InspectCommitComponent {
                 force_all,
                 self.components().as_slice(),
             );
-        }
 
-        out.push(
-            CommandInfo::new(
-                commands::CLOSE_POPUP,
+            out.push(
+                CommandInfo::new(commands::CLOSE_POPUP, true, true)
+                    .order(1),
+            );
+
+            out.push(CommandInfo::new(
+                commands::DIFF_FOCUS_RIGHT,
+                self.can_focus_diff(),
+                !self.diff.focused() || force_all,
+            ));
+
+            out.push(CommandInfo::new(
+                commands::DIFF_FOCUS_LEFT,
                 true,
-                self.is_visible(),
-            )
-            .order(1),
-        );
-
-        out.push(CommandInfo::new(
-            commands::DIFF_FOCUS_RIGHT,
-            self.can_focus_diff(),
-            (self.is_visible() && !self.diff.focused()) || force_all,
-        ));
-
-        out.push(CommandInfo::new(
-            commands::DIFF_FOCUS_LEFT,
-            true,
-            (self.is_visible() && self.diff.focused()) || force_all,
-        ));
+                self.diff.focused() || force_all,
+            ));
+        }
 
         visibility_blocking(self)
     }
@@ -154,11 +150,13 @@ impl InspectCommitComponent {
     pub fn new(
         queue: &Queue,
         sender: &Sender<AsyncNotification>,
-        theme: &Theme,
+        theme: SharedTheme,
     ) -> Self {
         Self {
             details: CommitDetailsComponent::new(
-                queue, sender, theme,
+                queue,
+                sender,
+                theme.clone(),
             ),
             diff: DiffComponent::new(None, theme),
             commit_id: None,
