@@ -4,6 +4,7 @@ mod commit;
 mod commit_details;
 mod commitlist;
 mod diff;
+mod externaleditor;
 mod filetree;
 mod help;
 mod inspect_commit;
@@ -12,14 +13,17 @@ mod reset;
 mod stashmsg;
 mod textinput;
 mod utils;
+
 use anyhow::Result;
+use crossterm::event::Event;
+
 pub use changes::ChangesComponent;
 pub use command::{CommandInfo, CommandText};
 pub use commit::CommitComponent;
 pub use commit_details::CommitDetailsComponent;
 pub use commitlist::CommitList;
-use crossterm::event::Event;
 pub use diff::DiffComponent;
+pub use externaleditor::ExternalEditorComponent;
 pub use filetree::FileTreeComponent;
 pub use help::HelpComponent;
 pub use inspect_commit::InspectCommitComponent;
@@ -120,7 +124,7 @@ pub fn visibility_blocking<T: Component>(
 pub trait DrawableComponent {
     ///
     fn draw<B: Backend>(
-        &mut self,
+        &self,
         f: &mut Frame<B>,
         rect: Rect,
     ) -> Result<()>;
