@@ -5,15 +5,15 @@ use crate::{
     },
     keys,
     queue::{Action, InternalEvent, Queue},
-    strings,
-    ui::style::Theme,
+    strings::{self, commands},
+    ui::style::SharedTheme,
 };
 use anyhow::Result;
-use asyncgit::sync;
-use asyncgit::CWD;
+use asyncgit::{
+    sync::{self, CommitId},
+    CWD,
+};
 use crossterm::event::Event;
-use strings::commands;
-use sync::CommitId;
 
 pub struct StashList {
     list: CommitList,
@@ -23,7 +23,7 @@ pub struct StashList {
 
 impl StashList {
     ///
-    pub fn new(queue: &Queue, theme: &Theme) -> Self {
+    pub fn new(queue: &Queue, theme: SharedTheme) -> Self {
         Self {
             visible: false,
             list: CommitList::new(strings::STASHLIST_TITLE, theme),
@@ -89,7 +89,7 @@ impl StashList {
 
 impl DrawableComponent for StashList {
     fn draw<B: tui::backend::Backend>(
-        &mut self,
+        &self,
         f: &mut tui::Frame<B>,
         rect: tui::layout::Rect,
     ) -> Result<()> {
